/*
 * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_zh extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "ADP", "ADP" },
            { "AED", "AED" },
            { "AFA", "AFA" },
            { "AFN", "AFN" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "AOK", "AOK" },
            { "AON", "AON" },
            { "AOR", "AOR" },
            { "ARA", "ARA" },
            { "ARL", "ARL" },
            { "ARM", "ARM" },
            { "ARP", "ARP" },
            { "ARS", "ARS" },
            { "ATS", "ATS" },
            { "AUD", "AU$" },
            { "AWG", "AWG" },
            { "AZM", "AZM" },
            { "AZN", "AZN" },
            { "BAD", "BAD" },
            { "BAM", "BAM" },
            { "BAN", "BAN" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BEC", "BEC" },
            { "BEF", "BEF" },
            { "BEL", "BEL" },
            { "BGL", "BGL" },
            { "BGM", "BGM" },
            { "BGN", "BGN" },
            { "BGO", "BGO" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BOL", "BOL" },
            { "BOP", "BOP" },
            { "BOV", "BOV" },
            { "BRB", "BRB" },
            { "BRC", "BRC" },
            { "BRE", "BRE" },
            { "BRN", "BRN" },
            { "BRR", "BRR" },
            { "BRZ", "BRZ" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BUK", "BUK" },
            { "BWP", "BWP" },
            { "BYB", "BYB" },
            { "BYN", "BYN" },
            { "BYR", "BYR" },
            { "BZD", "BZD" },
            { "CDF", "CDF" },
            { "CHE", "CHE" },
            { "CHF", "CHF" },
            { "CHW", "CHW" },
            { "CLE", "CLE" },
            { "CLF", "CLF" },
            { "CLP", "CLP" },
            { "CNH", "CNH" },
            { "CNY", "\u00a5" },
            { "COP", "COP" },
            { "COU", "COU" },
            { "CRC", "CRC" },
            { "CSD", "CSD" },
            { "CSK", "CSK" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CYP", "CYP" },
            { "CZK", "CZK" },
            { "DDM", "DDM" },
            { "DEM", "DEM" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "ECS", "ECS" },
            { "ECV", "ECV" },
            { "EEK", "EEK" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ESA", "ESA" },
            { "ESB", "ESB" },
            { "ESP", "ESP" },
            { "ETB", "ETB" },
            { "FIM", "FIM" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "FRF", "FRF" },
            { "GEK", "GEK" },
            { "GEL", "GEL" },
            { "GHC", "GHC" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GNS", "GNS" },
            { "GQE", "GQE" },
            { "GRD", "GRD" },
            { "GTQ", "GTQ" },
            { "GWE", "GWE" },
            { "GWP", "GWP" },
            { "GYD", "GYD" },
            { "HNL", "HNL" },
            { "HRD", "HRD" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IEP", "IEP" },
            { "ILP", "ILP" },
            { "ILR", "ILS" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISJ", "ISJ" },
            { "ISK", "ISK" },
            { "ITL", "ITL" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KRH", "KRH" },
            { "KRO", "KRO" },
            { "KRW", "\uffe6" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LSL", "LSL" },
            { "LTL", "LTL" },
            { "LTT", "LTT" },
            { "LUC", "LUC" },
            { "LUF", "LUF" },
            { "LUL", "LUL" },
            { "LVL", "LVL" },
            { "LVR", "LVR" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MAF", "MAF" },
            { "MCF", "MCF" },
            { "MDC", "MDC" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MGF", "MGF" },
            { "MKD", "MKD" },
            { "MKN", "MKN" },
            { "MLF", "MLF" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MRU", "MRU" },
            { "MTL", "MTL" },
            { "MTP", "MTP" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MXP", "MXP" },
            { "MXV", "MXV" },
            { "MYR", "MYR" },
            { "MZE", "MZE" },
            { "MZM", "MZM" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIC", "NIC" },
            { "NIO", "NIO" },
            { "NLG", "NLG" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEI", "PEI" },
            { "PEN", "PEN" },
            { "PES", "PES" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PLZ", "PLZ" },
            { "PTE", "PTE" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RHD", "RHD" },
            { "ROL", "ROL" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RUR", "RUR" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDD", "SDD" },
            { "SDG", "SDG" },
            { "SDP", "SDP" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SIT", "SIT" },
            { "SKK", "SKK" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SRG", "SRG" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "STN", "STN" },
            { "SUR", "SUR" },
            { "SVC", "SVC" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "THB" },
            { "TJR", "TJR" },
            { "TJS", "TJS" },
            { "TMM", "TMM" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TPE", "TPE" },
            { "TRL", "TRL" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UAK", "UAK" },
            { "UGS", "UGS" },
            { "UGX", "UGX" },
            { "USN", "USN" },
            { "USS", "USS" },
            { "UYI", "UYI" },
            { "UYP", "UYP" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEB", "VEB" },
            { "VEF", "VEF" },
            { "VES", "VES" },
            { "VNN", "VNN" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "XAG", "XAG" },
            { "XAU", "XAU" },
            { "XBA", "XBA" },
            { "XBB", "XBB" },
            { "XBC", "XBC" },
            { "XBD", "XBD" },
            { "XDR", "XDR" },
            { "XEU", "XEU" },
            { "XFO", "XFO" },
            { "XFU", "XFU" },
            { "XPD", "XPD" },
            { "XPT", "XPT" },
            { "XRE", "XRE" },
            { "XTS", "XTS" },
            { "XXX", "XXX" },
            { "YDD", "YDD" },
            { "YER", "YER" },
            { "YUD", "YUD" },
            { "YUM", "YUM" },
            { "YUN", "YUN" },
            { "YUR", "YUR" },
            { "ZAL", "ZAL" },
            { "ZAR", "ZAR" },
            { "ZMK", "ZMK" },
            { "ZMW", "ZMW" },
            { "ZRN", "ZRN" },
            { "ZRZ", "ZRZ" },
            { "ZWD", "ZWD" },
            { "ZWL", "ZWL" },
            { "ZWR", "ZWR" },
            { "adp", "\u5b89\u9053\u5c14\u6bd4\u585e\u5854" },
            { "aed", "\u963f\u8054\u914b\u8fea\u62c9\u59c6" },
            { "afa", "\u963f\u5bcc\u6c57\u5c3c (1927\u20132002)" },
            { "afn", "\u963f\u5bcc\u6c57\u5c3c" },
            { "alk", "\u963f\u5c14\u5df4\u5c3c\u4e9a\u5217\u514b(1946\u20131965)" },
            { "all", "\u963f\u5c14\u5df4\u5c3c\u4e9a\u5217\u514b" },
            { "amd", "\u4e9a\u7f8e\u5c3c\u4e9a\u5fb7\u62c9\u59c6" },
            { "ang", "\u8377\u5c5e\u5b89\u7684\u5217\u65af\u76fe" },
            { "aoa", "\u5b89\u54e5\u62c9\u5bbd\u624e" },
            { "aok", "\u5b89\u54e5\u62c9\u5bbd\u624e (1977\u20131990)" },
            { "aon", "\u5b89\u54e5\u62c9\u65b0\u5bbd\u624e (1990\u20132000)" },
            { "aor", "\u5b89\u54e5\u62c9\u91cd\u65b0\u8c03\u6574\u5bbd\u624e (1995\u20131999)" },
            { "ara", "\u963f\u6839\u5ef7\u5965\u65af\u7279\u62c9\u5c14" },
            { "arl", "\u963f\u6839\u5ef7\u6cd5\u5b9a\u6bd4\u7d22 (1970\u20131983)" },
            { "arm", "\u963f\u6839\u5ef7\u6bd4\u7d22 (1881\u20131970)" },
            { "arp", "\u963f\u6839\u5ef7\u6bd4\u7d22 (1983\u20131985)" },
            { "ars", "\u963f\u6839\u5ef7\u6bd4\u7d22" },
            { "ats", "\u5965\u5730\u5229\u5148\u4ee4" },
            { "aud", "\u6fb3\u5927\u5229\u4e9a\u5143" },
            { "awg", "\u963f\u9c81\u5df4\u5f17\u7f57\u6797" },
            { "azm", "\u963f\u585e\u62dc\u7586\u9a6c\u7eb3\u7279 (1993\u20132006)" },
            { "azn", "\u963f\u585e\u62dc\u7586\u9a6c\u7eb3\u7279" },
            { "bad", "\u6ce2\u58eb\u5c3c\u4e9a-\u8d6b\u585e\u54e5\u7ef4\u7eb3\u7b2c\u7eb3\u5c14 (1992\u20131994)" },
            { "bam", "\u6ce2\u65af\u5c3c\u4e9a-\u9ed1\u585e\u54e5\u7ef4\u90a3\u53ef\u5151\u6362\u9a6c\u514b" },
            { "ban", "\u6ce2\u58eb\u5c3c\u4e9a-\u8d6b\u585e\u54e5\u7ef4\u7eb3\u65b0\u7b2c\u7eb3\u5c14 (1994\u20131997)" },
            { "bbd", "\u5df4\u5df4\u591a\u65af\u5143" },
            { "bdt", "\u5b5f\u52a0\u62c9\u5854\u5361" },
            { "bec", "\u6bd4\u5229\u65f6\u6cd5\u90ce\uff08\u53ef\u5151\u6362\uff09" },
            { "bef", "\u6bd4\u5229\u65f6\u6cd5\u90ce" },
            { "bel", "\u6bd4\u5229\u65f6\u6cd5\u90ce\uff08\u91d1\u878d\uff09" },
            { "bgl", "\u4fdd\u52a0\u5229\u4e9a\u786c\u5217\u5f17" },
            { "bgm", "\u4fdd\u52a0\u5229\u4e9a\u793e\u4f1a\u515a\u5217\u5f17" },
            { "bgn", "\u4fdd\u52a0\u5229\u4e9a\u5217\u5f17" },
            { "bgo", "\u4fdd\u52a0\u5229\u4e9a\u5217\u5f17 (1879\u20131952)" },
            { "bhd", "\u5df4\u6797\u7b2c\u7eb3\u5c14" },
            { "bif", "\u5e03\u9686\u8fea\u6cd5\u90ce" },
            { "bmd", "\u767e\u6155\u5927\u5143" },
            { "bnd", "\u6587\u83b1\u5143" },
            { "bob", "\u73bb\u5229\u7ef4\u4e9a\u8bfa" },
            { "bol", "\u73bb\u5229\u7ef4\u4e9a\u8bfa (1863\u20131963)" },
            { "bop", "\u73bb\u5229\u7ef4\u4e9a\u6bd4\u7d22" },
            { "bov", "\u73bb\u5229\u7ef4\u4e9a Mvdol\uff08\u8d44\u91d1\uff09" },
            { "brb", "\u5df4\u897f\u65b0\u514b\u9c81\u8d5b\u7f57 (1967\u20131986)" },
            { "brc", "\u5df4\u897f\u514b\u9c81\u624e\u591a (1986\u20131989)" },
            { "bre", "\u5df4\u897f\u514b\u9c81\u585e\u7f57 (1990\u20131993)" },
            { "brl", "\u5df4\u897f\u96f7\u4e9a\u5c14" },
            { "brn", "\u5df4\u897f\u65b0\u514b\u9c81\u624e\u591a (1989\u20131990)" },
            { "brr", "\u5df4\u897f\u514b\u9c81\u585e\u7f57 (1993\u20131994)" },
            { "brz", "\u5df4\u897f\u514b\u9c81\u585e\u7f57 (1942\u20131967)" },
            { "bsd", "\u5df4\u54c8\u9a6c\u5143" },
            { "btn", "\u4e0d\u4e39\u52aa\u5c14\u7279\u9c81\u59c6" },
            { "buk", "\u7f05\u5143" },
            { "bwp", "\u535a\u8328\u74e6\u7eb3\u666e\u62c9" },
            { "byb", "\u767d\u4fc4\u7f57\u65af\u65b0\u5362\u5e03 (1994\u20131999)" },
            { "byn", "\u767d\u4fc4\u7f57\u65af\u5362\u5e03" },
            { "byr", "\u767d\u4fc4\u7f57\u65af\u5362\u5e03 (2000\u20132016)" },
            { "bzd", "\u4f2f\u5229\u5179\u5143" },
            { "cad", "\u52a0\u62ff\u5927\u5143" },
            { "cdf", "\u521a\u679c\u6cd5\u90ce" },
            { "che", "\u6b27\u5143 (WIR)" },
            { "chf", "\u745e\u58eb\u6cd5\u90ce" },
            { "chw", "\u6cd5\u90ce (WIR)" },
            { "cle", "\u667a\u5229\u57c3\u65af\u5e93\u591a" },
            { "clf", "\u667a\u5229\uff08\u8d44\u91d1\uff09" },
            { "clp", "\u667a\u5229\u6bd4\u7d22" },
            { "cnh", "\u4eba\u6c11\u5e01\uff08\u79bb\u5cb8\uff09" },
            { "cnx", "\u4e2d\u56fd\u4eba\u6c11\u94f6\u884c\u5143" },
            { "cny", "\u4eba\u6c11\u5e01" },
            { "cop", "\u54e5\u4f26\u6bd4\u4e9a\u6bd4\u7d22" },
            { "cou", "\u54e5\u4f26\u6bd4\u4e9a\u5e01" },
            { "crc", "\u54e5\u65af\u8fbe\u9ece\u52a0\u79d1\u6717" },
            { "csd", "\u65e7\u585e\u5c14\u7ef4\u4e9a\u7b2c\u7eb3\u5c14" },
            { "csk", "\u6377\u514b\u786c\u514b\u6717" },
            { "cuc", "\u53e4\u5df4\u53ef\u5151\u6362\u6bd4\u7d22" },
            { "cup", "\u53e4\u5df4\u6bd4\u7d22" },
            { "cve", "\u4f5b\u5f97\u89d2\u57c3\u65af\u5e93\u591a" },
            { "cyp", "\u585e\u6d66\u8def\u65af\u9551" },
            { "czk", "\u6377\u514b\u514b\u6717" },
            { "ddm", "\u4e1c\u5fb7\u5965\u65af\u7279\u9a6c\u514b" },
            { "dem", "\u5fb7\u56fd\u9a6c\u514b" },
            { "djf", "\u5409\u5e03\u63d0\u6cd5\u90ce" },
            { "dkk", "\u4e39\u9ea6\u514b\u6717" },
            { "dop", "\u591a\u7c73\u5c3c\u52a0\u6bd4\u7d22" },
            { "dzd", "\u963f\u5c14\u53ca\u5229\u4e9a\u7b2c\u7eb3\u5c14" },
            { "ecs", "\u5384\u74dc\u591a\u5c14\u82cf\u514b\u96f7" },
            { "ecv", "\u5384\u74dc\u591a\u5c14 (UVC)" },
            { "eek", "\u7231\u6c99\u5c3c\u4e9a\u514b\u6717" },
            { "egp", "\u57c3\u53ca\u9551" },
            { "ern", "\u5384\u7acb\u7279\u91cc\u4e9a\u7eb3\u514b\u6cd5" },
            { "esa", "\u897f\u73ed\u7259\u6bd4\u585e\u5854\uff08\u5e10\u6237 A\uff09" },
            { "esb", "\u897f\u73ed\u7259\u6bd4\u585e\u5854\uff08\u5151\u6362\u5e10\u6237\uff09" },
            { "esp", "\u897f\u73ed\u7259\u6bd4\u585e\u5854" },
            { "etb", "\u57c3\u585e\u4fc4\u6bd4\u4e9a\u6bd4\u5c14" },
            { "eur", "\u6b27\u5143" },
            { "fim", "\u82ac\u5170\u9a6c\u514b" },
            { "fjd", "\u6590\u6d4e\u5143" },
            { "fkp", "\u798f\u514b\u5170\u7fa4\u5c9b\u9551" },
            { "frf", "\u6cd5\u56fd\u6cd5\u90ce" },
            { "gbp", "\u82f1\u9551" },
            { "gek", "\u4e54\u6cbb\u4e9a\u5e93\u84ec\u62c9\u745e\u7279" },
            { "gel", "\u683c\u9c81\u5409\u4e9a\u62c9\u91cc" },
            { "ghc", "\u52a0\u7eb3\u585e\u7b2c" },
            { "ghs", "\u52a0\u7eb3\u585e\u5730" },
            { "gip", "\u76f4\u5e03\u7f57\u9640\u9551" },
            { "gmd", "\u5188\u6bd4\u4e9a\u8fbe\u62c9\u897f" },
            { "gnf", "\u51e0\u5185\u4e9a\u6cd5\u90ce" },
            { "gns", "\u51e0\u5185\u4e9a\u897f\u91cc" },
            { "gqe", "\u8d64\u9053\u51e0\u5185\u4e9a\u57c3\u594e\u52d2" },
            { "grd", "\u5e0c\u814a\u5fb7\u62c9\u514b\u9a6c" },
            { "gtq", "\u5371\u5730\u9a6c\u62c9\u683c\u67e5\u5c14" },
            { "gwe", "\u8461\u8404\u7259\u51e0\u5185\u4e9a\u57c3\u65af\u5e93\u591a" },
            { "gwp", "\u51e0\u5185\u4e9a\u6bd4\u7ecd\u6bd4\u7d22" },
            { "gyd", "\u572d\u4e9a\u90a3\u5143" },
            { "hkd", "\u6e2f\u5143" },
            { "hnl", "\u6d2a\u90fd\u62c9\u65af\u4f26\u76ae\u62c9" },
            { "hrd", "\u514b\u7f57\u5730\u4e9a\u7b2c\u7eb3\u5c14" },
            { "hrk", "\u514b\u7f57\u5730\u4e9a\u5e93\u7eb3" },
            { "htg", "\u6d77\u5730\u53e4\u5fb7" },
            { "huf", "\u5308\u7259\u5229\u798f\u6797" },
            { "idr", "\u5370\u5ea6\u5c3c\u897f\u4e9a\u76fe" },
            { "iep", "\u7231\u5c14\u5170\u9551" },
            { "ilp", "\u4ee5\u8272\u5217\u9551" },
            { "ilr", "\u4ee5\u8272\u5217\u8c22\u514b\u5c14(1980\u20131985)" },
            { "ils", "\u4ee5\u8272\u5217\u65b0\u8c22\u514b\u5c14" },
            { "inr", "\u5370\u5ea6\u5362\u6bd4" },
            { "iqd", "\u4f0a\u62c9\u514b\u7b2c\u7eb3\u5c14" },
            { "irr", "\u4f0a\u6717\u91cc\u4e9a\u5c14" },
            { "isj", "\u51b0\u5c9b\u514b\u6717(1918\u20131981)" },
            { "isk", "\u51b0\u5c9b\u514b\u6717" },
            { "itl", "\u610f\u5927\u5229\u91cc\u62c9" },
            { "jmd", "\u7259\u4e70\u52a0\u5143" },
            { "jod", "\u7ea6\u65e6\u7b2c\u7eb3\u5c14" },
            { "jpy", "\u65e5\u5143" },
            { "kes", "\u80af\u5c3c\u4e9a\u5148\u4ee4" },
            { "kgs", "\u5409\u5c14\u5409\u65af\u65af\u5766\u7d22\u59c6" },
            { "khr", "\u67ec\u57d4\u5be8\u745e\u5c14" },
            { "kmf", "\u79d1\u6469\u7f57\u6cd5\u90ce" },
            { "kpw", "\u671d\u9c9c\u5143" },
            { "krh", "\u97e9\u5143 (1953\u20131962)" },
            { "kro", "\u97e9\u5143 (1945\u20131953)" },
            { "krw", "\u97e9\u5143" },
            { "kwd", "\u79d1\u5a01\u7279\u7b2c\u7eb3\u5c14" },
            { "kyd", "\u5f00\u66fc\u5143" },
            { "kzt", "\u54c8\u8428\u514b\u65af\u5766\u575a\u6208" },
            { "lak", "\u8001\u631d\u57fa\u666e" },
            { "lbp", "\u9ece\u5df4\u5ae9\u9551" },
            { "lkr", "\u65af\u91cc\u5170\u5361\u5362\u6bd4" },
            { "lrd", "\u5229\u6bd4\u91cc\u4e9a\u5143" },
            { "lsl", "\u83b1\u7d22\u6258\u6d1b\u8482" },
            { "ltl", "\u7acb\u9676\u5b9b\u7acb\u7279" },
            { "ltt", "\u7acb\u9676\u5b9b\u5854\u54af\u5450\u53f8" },
            { "luc", "\u5362\u68ee\u5821\u53ef\u5151\u6362\u6cd5\u90ce" },
            { "luf", "\u5362\u68ee\u5821\u6cd5\u90ce" },
            { "lul", "\u5362\u68ee\u5821\u91d1\u878d\u6cd5\u90ce" },
            { "lvl", "\u62c9\u8131\u7ef4\u4e9a\u62c9\u7279" },
            { "lvr", "\u62c9\u8131\u7ef4\u4e9a\u5362\u5e03" },
            { "lyd", "\u5229\u6bd4\u4e9a\u7b2c\u7eb3\u5c14" },
            { "mad", "\u6469\u6d1b\u54e5\u8fea\u62c9\u59c6" },
            { "maf", "\u6469\u6d1b\u54e5\u6cd5\u90ce" },
            { "mcf", "\u6469\u7eb3\u54e5\u6cd5\u90ce" },
            { "mdc", "\u6469\u5c14\u591a\u74e6\u5e93\u90a6" },
            { "mdl", "\u6469\u5c14\u591a\u74e6\u5217\u4f0a" },
            { "mga", "\u9a6c\u8fbe\u52a0\u65af\u52a0\u963f\u91cc\u4e9a\u91cc" },
            { "mgf", "\u9a6c\u8fbe\u52a0\u65af\u52a0\u6cd5\u90ce" },
            { "mkd", "\u9a6c\u5176\u987f\u7b2c\u7eb3\u5c14" },
            { "mkn", "\u9a6c\u5176\u987f\u7b2c\u7eb3\u5c14 (1992\u20131993)" },
            { "mlf", "\u9a6c\u91cc\u6cd5\u90ce" },
            { "mmk", "\u7f05\u7538\u5143" },
            { "mnt", "\u8499\u53e4\u56fe\u683c\u91cc\u514b" },
            { "mop", "\u6fb3\u95e8\u5e01" },
            { "mro", "\u6bdb\u91cc\u5854\u5c3c\u4e9a\u4e4c\u5409\u4e9a (1973\u20132017)" },
            { "mru", "\u6bdb\u91cc\u5854\u5c3c\u4e9a\u4e4c\u5409\u4e9a" },
            { "mtl", "\u9a6c\u8033\u4ed6\u91cc\u62c9" },
            { "mtp", "\u9a6c\u8033\u4ed6\u9551" },
            { "mur", "\u6bdb\u91cc\u6c42\u65af\u5362\u6bd4" },
            { "mvp", "\u9a6c\u5c14\u4ee3\u592b\u5362\u6bd4(1947\u20131981)" },
            { "mvr", "\u9a6c\u5c14\u4ee3\u592b\u5362\u83f2\u4e9a" },
            { "mwk", "\u9a6c\u62c9\u7ef4\u514b\u74e6\u67e5" },
            { "mxn", "\u58a8\u897f\u54e5\u6bd4\u7d22" },
            { "mxp", "\u58a8\u897f\u54e5\u94f6\u6bd4\u7d22 (1861\u20131992)" },
            { "mxv", "\u58a8\u897f\u54e5\uff08\u8d44\u91d1\uff09" },
            { "myr", "\u9a6c\u6765\u897f\u4e9a\u6797\u5409\u7279" },
            { "mze", "\u83ab\u6851\u6bd4\u514b\u57c3\u65af\u5e93\u591a" },
            { "mzm", "\u65e7\u83ab\u6851\u6bd4\u514b\u7f8e\u63d0\u5361" },
            { "mzn", "\u83ab\u6851\u6bd4\u514b\u7f8e\u63d0\u5361" },
            { "nad", "\u7eb3\u7c73\u6bd4\u4e9a\u5143" },
            { "ngn", "\u5c3c\u65e5\u5229\u4e9a\u5948\u62c9" },
            { "nic", "\u5c3c\u52a0\u62c9\u74dc\u79d1\u591a\u5df4 (1988\u20131991)" },
            { "nio", "\u5c3c\u52a0\u62c9\u74dc\u79d1\u591a\u5df4" },
            { "nlg", "\u8377\u5170\u76fe" },
            { "nok", "\u632a\u5a01\u514b\u6717" },
            { "npr", "\u5c3c\u6cca\u5c14\u5362\u6bd4" },
            { "nzd", "\u65b0\u897f\u5170\u5143" },
            { "omr", "\u963f\u66fc\u91cc\u4e9a\u5c14" },
            { "pab", "\u5df4\u62ff\u9a6c\u5df4\u6ce2\u4e9a" },
            { "pei", "\u79d8\u9c81\u5370\u7b2c" },
            { "pen", "\u79d8\u9c81\u7d22\u5c14" },
            { "pes", "\u79d8\u9c81\u7d22\u5c14 (1863\u20131965)" },
            { "pgk", "\u5df4\u5e03\u4e9a\u65b0\u51e0\u5185\u4e9a\u57fa\u90a3" },
            { "php", "\u83f2\u5f8b\u5bbe\u6bd4\u7d22" },
            { "pkr", "\u5df4\u57fa\u65af\u5766\u5362\u6bd4" },
            { "pln", "\u6ce2\u5170\u5179\u7f57\u63d0" },
            { "plz", "\u6ce2\u5170\u5179\u7f57\u63d0 (1950\u20131995)" },
            { "pte", "\u8461\u8404\u7259\u57c3\u65af\u5e93\u591a" },
            { "pyg", "\u5df4\u62c9\u572d\u74dc\u62c9\u5c3c" },
            { "qar", "\u5361\u5854\u5c14\u91cc\u4e9a\u5c14" },
            { "rhd", "\u7f57\u5f97\u897f\u4e9a\u5143" },
            { "rol", "\u65e7\u7f57\u9a6c\u5c3c\u4e9a\u5217\u4f0a" },
            { "ron", "\u7f57\u9a6c\u5c3c\u4e9a\u5217\u4f0a" },
            { "rsd", "\u585e\u5c14\u7ef4\u4e9a\u7b2c\u7eb3\u5c14" },
            { "rub", "\u4fc4\u7f57\u65af\u5362\u5e03" },
            { "rur", "\u4fc4\u56fd\u5362\u5e03 (1991\u20131998)" },
            { "rwf", "\u5362\u65fa\u8fbe\u6cd5\u90ce" },
            { "sar", "\u6c99\u7279\u91cc\u4e9a\u5c14" },
            { "sbd", "\u6240\u7f57\u95e8\u7fa4\u5c9b\u5143" },
            { "scr", "\u585e\u820c\u5c14\u5362\u6bd4" },
            { "sdd", "\u82cf\u4e39\u7b2c\u7eb3\u5c14 (1992\u20132007)" },
            { "sdg", "\u82cf\u4e39\u9551" },
            { "sdp", "\u65e7\u82cf\u4e39\u9551" },
            { "sek", "\u745e\u5178\u514b\u6717" },
            { "sgd", "\u65b0\u52a0\u5761\u5143" },
            { "shp", "\u5723\u8d6b\u52d2\u62ff\u7fa4\u5c9b\u78c5" },
            { "sit", "\u65af\u6d1b\u6587\u5c3c\u4e9a\u6258\u62c9\u5c14" },
            { "skk", "\u65af\u6d1b\u4f10\u514b\u514b\u6717" },
            { "sll", "\u585e\u62c9\u5229\u6602\u5229\u6602" },
            { "sos", "\u7d22\u9a6c\u91cc\u5148\u4ee4" },
            { "srd", "\u82cf\u91cc\u5357\u5143" },
            { "srg", "\u82cf\u91cc\u5357\u76fe" },
            { "ssp", "\u5357\u82cf\u4e39\u9551" },
            { "std", "\u5723\u591a\u7f8e\u548c\u666e\u6797\u897f\u6bd4\u591a\u5e03\u62c9 (1977\u20132017)" },
            { "stn", "\u5723\u591a\u7f8e\u548c\u666e\u6797\u897f\u6bd4\u591a\u5e03\u62c9" },
            { "sur", "\u82cf\u8054\u5362\u5e03" },
            { "svc", "\u8428\u5c14\u74e6\u591a\u79d1\u6717" },
            { "syp", "\u53d9\u5229\u4e9a\u9551" },
            { "szl", "\u65af\u5a01\u58eb\u5170\u91cc\u5170\u5409\u5c3c" },
            { "thb", "\u6cf0\u94e2" },
            { "tjr", "\u5854\u5409\u514b\u65af\u5766\u5362\u5e03" },
            { "tjs", "\u5854\u5409\u514b\u65af\u5766\u7d22\u83ab\u5c3c" },
            { "tmm", "\u571f\u5e93\u66fc\u65af\u5766\u9a6c\u7eb3\u7279 (1993\u20132009)" },
            { "tmt", "\u571f\u5e93\u66fc\u65af\u5766\u9a6c\u7eb3\u7279" },
            { "tnd", "\u7a81\u5c3c\u65af\u7b2c\u7eb3\u5c14" },
            { "top", "\u6c64\u52a0\u6f58\u52a0" },
            { "tpe", "\u5e1d\u6c76\u57c3\u65af\u5e93\u591a" },
            { "trl", "\u571f\u8033\u5176\u91cc\u62c9 (1922\u20132005)" },
            { "try", "\u571f\u8033\u5176\u91cc\u62c9" },
            { "ttd", "\u7279\u7acb\u5c3c\u8fbe\u548c\u591a\u5df4\u54e5\u5143" },
            { "twd", "\u65b0\u53f0\u5e01" },
            { "tzs", "\u5766\u6851\u5c3c\u4e9a\u5148\u4ee4" },
            { "uah", "\u4e4c\u514b\u5170\u683c\u91cc\u592b\u7eb3" },
            { "uak", "\u4e4c\u514b\u5170\u5e01" },
            { "ugs", "\u4e4c\u5e72\u8fbe\u5148\u4ee4 (1966\u20131987)" },
            { "ugx", "\u4e4c\u5e72\u8fbe\u5148\u4ee4" },
            { "usd", "\u7f8e\u5143" },
            { "usn", "\u7f8e\u5143\uff08\u6b21\u65e5\uff09" },
            { "uss", "\u7f8e\u5143\uff08\u5f53\u65e5\uff09" },
            { "uyi", "\u4e4c\u62c9\u572d\u6bd4\u7d22\uff08\u7d22\u5f15\u5355\u4f4d\uff09" },
            { "uyp", "\u4e4c\u62c9\u572d\u6bd4\u7d22 (1975\u20131993)" },
            { "uyu", "\u4e4c\u62c9\u572d\u6bd4\u7d22" },
            { "uyw", "\u4e4c\u62c9\u572d\u7968\u9762\u5de5\u8d44\u6307\u6570\u5355\u4f4d" },
            { "uzs", "\u4e4c\u5179\u522b\u514b\u65af\u5766\u82cf\u59c6" },
            { "veb", "\u59d4\u5185\u745e\u62c9\u73bb\u5229\u74e6\u5c14 (1871\u20132008)" },
            { "vef", "\u59d4\u5185\u745e\u62c9\u73bb\u5229\u74e6\u5c14 (2008\u20132018)" },
            { "ves", "\u59d4\u5185\u745e\u62c9\u73bb\u5229\u74e6\u5c14" },
            { "vnd", "\u8d8a\u5357\u76fe" },
            { "vnn", "\u8d8a\u5357\u76fe (1978\u20131985)" },
            { "vuv", "\u74e6\u52aa\u963f\u56fe\u74e6\u56fe" },
            { "wst", "\u8428\u6469\u4e9a\u5854\u62c9" },
            { "xaf", "\u4e2d\u975e\u6cd5\u90ce" },
            { "xag", "\u94f6" },
            { "xau", "\u9ec4\u91d1" },
            { "xba", "\u6b27\u6d32\u590d\u5408\u5355\u4f4d" },
            { "xbb", "\u6b27\u6d32\u8d27\u5e01\u8054\u76df" },
            { "xbc", "\u6b27\u6d32\u8ba1\u7b97\u5355\u4f4d (XBC)" },
            { "xbd", "\u6b27\u6d32\u8ba1\u7b97\u5355\u4f4d (XBD)" },
            { "xcd", "\u4e1c\u52a0\u52d2\u6bd4\u5143" },
            { "xdr", "\u7279\u522b\u63d0\u6b3e\u6743" },
            { "xeu", "\u6b27\u6d32\u8d27\u5e01\u5355\u4f4d" },
            { "xfo", "\u6cd5\u56fd\u91d1\u6cd5\u90ce" },
            { "xfu", "\u6cd5\u56fd\u6cd5\u90ce (UIC)" },
            { "xof", "\u897f\u975e\u6cd5\u90ce" },
            { "xpd", "\u94af" },
            { "xpf", "\u592a\u5e73\u6d0b\u6cd5\u90ce" },
            { "xpt", "\u94c2" },
            { "xre", "RINET \u57fa\u91d1" },
            { "xsu", "\u82cf\u514b\u96f7" },
            { "xts", "\u6d4b\u8bd5\u8d27\u5e01\u4ee3\u7801" },
            { "xua", "\u975e\u6d32\u5f00\u53d1\u94f6\u884c\u8bb0\u8d26\u5355\u4f4d" },
            { "xxx", "\u672a\u77e5\u8d27\u5e01" },
            { "ydd", "\u4e5f\u95e8\u7b2c\u7eb3\u5c14" },
            { "yer", "\u4e5f\u95e8\u91cc\u4e9a\u5c14" },
            { "yud", "\u5357\u65af\u62c9\u592b\u786c\u7b2c\u7eb3\u5c14 (1966\u20131990)" },
            { "yum", "\u5357\u65af\u62c9\u592b\u65b0\u7b2c\u7eb3\u5c14 (1994\u20132002)" },
            { "yun", "\u5357\u65af\u62c9\u592b\u53ef\u5151\u6362\u7b2c\u7eb3\u5c14 (1990\u20131992)" },
            { "yur", "\u5357\u65af\u62c9\u592b\u6539\u826f\u7b2c\u7eb3\u5c14 (1992\u20131993)" },
            { "zal", "\u5357\u975e\u5170\u7279 (\u91d1\u878d)" },
            { "zar", "\u5357\u975e\u5170\u7279" },
            { "zmk", "\u8d5e\u6bd4\u4e9a\u514b\u74e6\u67e5 (1968\u20132012)" },
            { "zmw", "\u8d5e\u6bd4\u4e9a\u514b\u74e6\u67e5" },
            { "zrn", "\u65b0\u624e\u4f0a\u5c14 (1993\u20131998)" },
            { "zrz", "\u624e\u4f0a\u5c14 (1971\u20131993)" },
            { "zwd", "\u6d25\u5df4\u5e03\u97e6\u5143 (1980\u20132008)" },
            { "zwl", "\u6d25\u5df4\u5e03\u97e6\u5143 (2009)" },
            { "zwr", "\u6d25\u5df4\u5e03\u97e6\u5143 (2008)" },
        };
        return data;
    }
}
